Class: OnebusawaySDK::Models::ArrivalsAndDeparturesForLocationListParams

Inherits:
Internal::Type::BaseModel show all
Extended by:
Internal::Type::RequestParameters::Converter
Includes:
Internal::Type::RequestParameters
Defined in:
lib/onebusaway_sdk/models/arrivals_and_departures_for_location_list_params.rb

Overview

Instance Attribute Summary collapse

Attributes included from Internal::Type::RequestParameters

#request_options

Instance Method Summary collapse

Methods included from Internal::Type::RequestParameters::Converter

dump_request

Methods included from Internal::Type::RequestParameters

included

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(lat:, lon:, empty_returns_not_found: nil, lat_span: nil, lon_span: nil, max_count: nil, minutes_after: nil, minutes_before: nil, radius: nil, route_type: nil, time: nil, request_options: {}) ⇒ Object

Some parameter documentations has been truncated, see OnebusawaySDK::Models::ArrivalsAndDeparturesForLocationListParams for more details.

Parameters:

  • lat (Float)

    The latitude coordinate of the search center.

  • lon (Float)

    The longitude coordinate of the search center.

  • empty_returns_not_found (Boolean) (defaults to: nil)

    If true, returns a 404 Not Found error instead of an empty result.

  • lat_span (Float) (defaults to: nil)

    Sets the latitude limits of the search bounding box.

  • lon_span (Float) (defaults to: nil)

    Sets the longitude limits of the search bounding box.

  • max_count (Integer) (defaults to: nil)

    The max size of the list of nearby stops and arrivals to return. Defaults to 250

  • minutes_after (Integer) (defaults to: nil)

    Include arrivals and departures this many minutes after the query time.

  • minutes_before (Integer) (defaults to: nil)

    Include arrivals and departures this many minutes before the query time.

  • radius (Float) (defaults to: nil)

    The search radius in meters.

  • route_type (String) (defaults to: nil)

    Optional list of GTFS routeTypes to filter by (comma delimited) e.g. “1,2,3”.

  • time (Integer) (defaults to: nil)

    By default, returns the status right now. Can be queried at a specific time (mil

  • request_options (OnebusawaySDK::RequestOptions, Hash{Symbol=>Object}) (defaults to: {})


# File 'lib/onebusaway_sdk/models/arrivals_and_departures_for_location_list_params.rb', line 78

Instance Attribute Details

#empty_returns_not_foundBoolean?

If true, returns a 404 Not Found error instead of an empty result.

Returns:

  • (Boolean, nil)


26
# File 'lib/onebusaway_sdk/models/arrivals_and_departures_for_location_list_params.rb', line 26

optional :empty_returns_not_found, OnebusawaySDK::Internal::Type::Boolean

#latFloat

The latitude coordinate of the search center.

Returns:

  • (Float)


14
# File 'lib/onebusaway_sdk/models/arrivals_and_departures_for_location_list_params.rb', line 14

required :lat, Float

#lat_spanFloat?

Sets the latitude limits of the search bounding box.

Returns:

  • (Float, nil)


32
# File 'lib/onebusaway_sdk/models/arrivals_and_departures_for_location_list_params.rb', line 32

optional :lat_span, Float

#lonFloat

The longitude coordinate of the search center.

Returns:

  • (Float)


20
# File 'lib/onebusaway_sdk/models/arrivals_and_departures_for_location_list_params.rb', line 20

required :lon, Float

#lon_spanFloat?

Sets the longitude limits of the search bounding box.

Returns:

  • (Float, nil)


38
# File 'lib/onebusaway_sdk/models/arrivals_and_departures_for_location_list_params.rb', line 38

optional :lon_span, Float

#max_countInteger?

The max size of the list of nearby stops and arrivals to return. Defaults to 250, max 1000.

Returns:

  • (Integer, nil)


45
# File 'lib/onebusaway_sdk/models/arrivals_and_departures_for_location_list_params.rb', line 45

optional :max_count, Integer

#minutes_afterInteger?

Include arrivals and departures this many minutes after the query time.

Returns:

  • (Integer, nil)


51
# File 'lib/onebusaway_sdk/models/arrivals_and_departures_for_location_list_params.rb', line 51

optional :minutes_after, Integer

#minutes_beforeInteger?

Include arrivals and departures this many minutes before the query time.

Returns:

  • (Integer, nil)


57
# File 'lib/onebusaway_sdk/models/arrivals_and_departures_for_location_list_params.rb', line 57

optional :minutes_before, Integer

#radiusFloat?

The search radius in meters.

Returns:

  • (Float, nil)


63
# File 'lib/onebusaway_sdk/models/arrivals_and_departures_for_location_list_params.rb', line 63

optional :radius, Float

#route_typeString?

Optional list of GTFS routeTypes to filter by (comma delimited) e.g. “1,2,3”.

Returns:

  • (String, nil)


69
# File 'lib/onebusaway_sdk/models/arrivals_and_departures_for_location_list_params.rb', line 69

optional :route_type, String

#timeInteger?

By default, returns the status right now. Can be queried at a specific time (milliseconds since epoch) for testing.

Returns:

  • (Integer, nil)


76
# File 'lib/onebusaway_sdk/models/arrivals_and_departures_for_location_list_params.rb', line 76

optional :time, Integer