Class: OnebusawaySDK::Models::ArrivalsAndDeparturesForLocationListResponse::Data::Entry

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/onebusaway_sdk/models/arrivals_and_departures_for_location_list_response.rb

Overview

See Also:

Defined Under Namespace

Classes: ArrivalsAndDeparture, NearbyStopID

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(lat: nil, lon: nil) ⇒ Object

Current position of the transit vehicle.

Parameters:

  • lat (Float) (defaults to: nil)

    Latitude of the current position of the transit vehicle.

  • lon (Float) (defaults to: nil)

    Longitude of the current position of the transit vehicle.



# File 'lib/onebusaway_sdk/models/arrivals_and_departures_for_location_list_response.rb', line 626

Instance Attribute Details

#arrivals_and_departuresArray<OnebusawaySDK::Models::ArrivalsAndDeparturesForLocationListResponse::Data::Entry::ArrivalsAndDeparture>



35
36
37
# File 'lib/onebusaway_sdk/models/arrivals_and_departures_for_location_list_response.rb', line 35

required :arrivals_and_departures,
-> { OnebusawaySDK::Internal::Type::ArrayOf[OnebusawaySDK::Models::ArrivalsAndDeparturesForLocationListResponse::Data::Entry::ArrivalsAndDeparture] },
api_name: :arrivalsAndDepartures

#limit_exceededBoolean

Returns:

  • (Boolean)


42
# File 'lib/onebusaway_sdk/models/arrivals_and_departures_for_location_list_response.rb', line 42

required :limit_exceeded, OnebusawaySDK::Internal::Type::Boolean, api_name: :limitExceeded

#nearby_stop_idsArray<OnebusawaySDK::Models::ArrivalsAndDeparturesForLocationListResponse::Data::Entry::NearbyStopID>



47
48
49
# File 'lib/onebusaway_sdk/models/arrivals_and_departures_for_location_list_response.rb', line 47

required :nearby_stop_ids,
-> { OnebusawaySDK::Internal::Type::ArrayOf[OnebusawaySDK::Models::ArrivalsAndDeparturesForLocationListResponse::Data::Entry::NearbyStopID] },
api_name: :nearbyStopIds

#situation_idsArray<String>?

Returns:

  • (Array<String>, nil)


59
# File 'lib/onebusaway_sdk/models/arrivals_and_departures_for_location_list_response.rb', line 59

optional :situation_ids, OnebusawaySDK::Internal::Type::ArrayOf[String], api_name: :situationIds

#stop_idsArray<String>

Returns:

  • (Array<String>)


54
# File 'lib/onebusaway_sdk/models/arrivals_and_departures_for_location_list_response.rb', line 54

required :stop_ids, OnebusawaySDK::Internal::Type::ArrayOf[String], api_name: :stopIds