Class: OnebusawaySDK::Models::ArrivalsAndDeparturesForLocationListResponse::Data::Entry::ArrivalsAndDeparture::TripStatus::Position
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- OnebusawaySDK::Models::ArrivalsAndDeparturesForLocationListResponse::Data::Entry::ArrivalsAndDeparture::TripStatus::Position
- Defined in:
- lib/onebusaway_sdk/models/arrivals_and_departures_for_location_list_response.rb,
sig/onebusaway_sdk/models/arrivals_and_departures_for_location_list_response.rbs
Overview
Instance Attribute Summary collapse
-
#lat ⇒ Float?
Latitude of the current position of the transit vehicle.
-
#lon ⇒ Float?
Longitude of the current position of the transit vehicle.
Instance Method Summary collapse
-
#initialize ⇒ Position
constructor
A new instance of Position.
- #to_hash ⇒ { lat: Float, lon: Float }
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize ⇒ Position
Returns a new instance of Position.
484 |
# File 'sig/onebusaway_sdk/models/arrivals_and_departures_for_location_list_response.rbs', line 484
def initialize: (?lat: Float, ?lon: Float) -> void
|
Instance Attribute Details
#lat ⇒ Float?
Latitude of the current position of the transit vehicle.
618 |
# File 'lib/onebusaway_sdk/models/arrivals_and_departures_for_location_list_response.rb', line 618 optional :lat, Float |
#lon ⇒ Float?
Longitude of the current position of the transit vehicle.
624 |
# File 'lib/onebusaway_sdk/models/arrivals_and_departures_for_location_list_response.rb', line 624 optional :lon, Float |
Instance Method Details
#to_hash ⇒ { lat: Float, lon: Float }
486 |
# File 'sig/onebusaway_sdk/models/arrivals_and_departures_for_location_list_response.rbs', line 486
def to_hash: -> { lat: Float, lon: Float }
|