Class: OnebusawaySDK::Models::References::Situation::PublicationWindow
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- OnebusawaySDK::Models::References::Situation::PublicationWindow
- Defined in:
- lib/onebusaway_sdk/models/references.rb,
sig/onebusaway_sdk/models/references.rbs
Instance Attribute Summary collapse
-
#from ⇒ Integer
Start time of the time window as a Unix timestamp.
-
#to ⇒ Integer
End time of the time window as a Unix timestamp.
Instance Method Summary collapse
-
#initialize ⇒ PublicationWindow
constructor
A new instance of PublicationWindow.
- #to_hash ⇒ { from: Integer, to: Integer }
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize ⇒ PublicationWindow
Returns a new instance of PublicationWindow.
477 |
# File 'sig/onebusaway_sdk/models/references.rbs', line 477
def initialize: (from: Integer, to: Integer) -> void
|
Instance Attribute Details
#from ⇒ Integer
Start time of the time window as a Unix timestamp.
444 |
# File 'lib/onebusaway_sdk/models/references.rb', line 444 required :from, Integer |
#to ⇒ Integer
End time of the time window as a Unix timestamp.
450 |
# File 'lib/onebusaway_sdk/models/references.rb', line 450 required :to, Integer |
Instance Method Details
#to_hash ⇒ { from: Integer, to: Integer }
479 |
# File 'sig/onebusaway_sdk/models/references.rbs', line 479
def to_hash: -> { from: Integer, to: Integer }
|