Class: OnebusawaySDK::Models::ShapeRetrieveResponse::Data

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/onebusaway_sdk/models/shape_retrieve_response.rb

Defined Under Namespace

Classes: Entry

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(entry:, references:) ⇒ Object



15
16
17
18
19
20
21
22
23
24
25
26
27
28
29
30
31
32
33
34
35
36
37
38
39
40
41
42
43
44
45
46
47
48
49
50
51
52
53
54
55
# File 'lib/onebusaway_sdk/models/shape_retrieve_response.rb', line 15

class Data < OnebusawaySDK::Internal::Type::BaseModel
  # @!attribute entry
  #
  #   @return [OnebusawaySDK::Models::ShapeRetrieveResponse::Data::Entry]
  required :entry, -> { OnebusawaySDK::Models::ShapeRetrieveResponse::Data::Entry }

  # @!attribute references
  #
  #   @return [OnebusawaySDK::Models::References]
  required :references, -> { OnebusawaySDK::References }

  # @!method initialize(entry:, references:)
  #   @param entry [OnebusawaySDK::Models::ShapeRetrieveResponse::Data::Entry]
  #   @param references [OnebusawaySDK::Models::References]

  # @see OnebusawaySDK::Models::ShapeRetrieveResponse::Data#entry
  class Entry < OnebusawaySDK::Internal::Type::BaseModel
    # @!attribute length
    #
    #   @return [Integer]
    required :length, Integer

    # @!attribute points
    #   Encoded polyline format representing the shape of the path
    #
    #   @return [String]
    required :points, String

    # @!attribute levels
    #
    #   @return [String, nil]
    optional :levels, String

    # @!method initialize(length:, points:, levels: nil)
    #   @param length [Integer]
    #
    #   @param points [String] Encoded polyline format representing the shape of the path
    #
    #   @param levels [String]
  end
end

Instance Attribute Details

#entryOnebusawaySDK::Models::ShapeRetrieveResponse::Data::Entry



19
# File 'lib/onebusaway_sdk/models/shape_retrieve_response.rb', line 19

required :entry, -> { OnebusawaySDK::Models::ShapeRetrieveResponse::Data::Entry }

#referencesOnebusawaySDK::Models::References



24
# File 'lib/onebusaway_sdk/models/shape_retrieve_response.rb', line 24

required :references, -> { OnebusawaySDK::References }