Class: OnebusawaySDK::Models::TripDetailRetrieveParams

Inherits:
Internal::Type::BaseModel show all
Extended by:
Internal::Type::RequestParameters::Converter
Includes:
Internal::Type::RequestParameters
Defined in:
lib/onebusaway_sdk/models/trip_detail_retrieve_params.rb

Overview

Instance Attribute Summary collapse

Attributes included from Internal::Type::RequestParameters

#request_options

Instance Method Summary collapse

Methods included from Internal::Type::RequestParameters::Converter

dump_request

Methods included from Internal::Type::RequestParameters

included

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(trip_id:, include_schedule: nil, include_status: nil, include_trip: nil, service_date: nil, time: nil, request_options: {}) ⇒ Object

Some parameter documentations has been truncated, see OnebusawaySDK::Models::TripDetailRetrieveParams for more details.

Parameters:

  • trip_id (String)
  • include_schedule (Boolean) (defaults to: nil)

    Whether to include the full schedule element in the tripDetails section (default

  • include_status (Boolean) (defaults to: nil)

    Whether to include the full status element in the tripDetails section (defaults

  • include_trip (Boolean) (defaults to: nil)

    Whether to include the full trip element in the references section (defaults to

  • service_date (Integer) (defaults to: nil)

    Service date for the trip as Unix time in milliseconds (optional).

  • time (Integer) (defaults to: nil)

    Time parameter to query the system at a specific time (optional).

  • request_options (OnebusawaySDK::RequestOptions, Hash{Symbol=>Object}) (defaults to: {})


# File 'lib/onebusaway_sdk/models/trip_detail_retrieve_params.rb', line 48

Instance Attribute Details

#include_scheduleBoolean?

Whether to include the full schedule element in the tripDetails section (defaults to true).

Returns:

  • (Boolean, nil)


20
# File 'lib/onebusaway_sdk/models/trip_detail_retrieve_params.rb', line 20

optional :include_schedule, OnebusawaySDK::Internal::Type::Boolean

#include_statusBoolean?

Whether to include the full status element in the tripDetails section (defaults to true).

Returns:

  • (Boolean, nil)


27
# File 'lib/onebusaway_sdk/models/trip_detail_retrieve_params.rb', line 27

optional :include_status, OnebusawaySDK::Internal::Type::Boolean

#include_tripBoolean?

Whether to include the full trip element in the references section (defaults to true).

Returns:

  • (Boolean, nil)


34
# File 'lib/onebusaway_sdk/models/trip_detail_retrieve_params.rb', line 34

optional :include_trip, OnebusawaySDK::Internal::Type::Boolean

#service_dateInteger?

Service date for the trip as Unix time in milliseconds (optional).

Returns:

  • (Integer, nil)


40
# File 'lib/onebusaway_sdk/models/trip_detail_retrieve_params.rb', line 40

optional :service_date, Integer

#timeInteger?

Time parameter to query the system at a specific time (optional).

Returns:

  • (Integer, nil)


46
# File 'lib/onebusaway_sdk/models/trip_detail_retrieve_params.rb', line 46

optional :time, Integer

#trip_idString

Returns:

  • (String)


13
# File 'lib/onebusaway_sdk/models/trip_detail_retrieve_params.rb', line 13

required :trip_id, String