Class: OnebusawaySDK::Models::TripForVehicleRetrieveParams
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- OnebusawaySDK::Models::TripForVehicleRetrieveParams
- Extended by:
- Internal::Type::RequestParameters::Converter
- Includes:
- Internal::Type::RequestParameters
- Defined in:
- lib/onebusaway_sdk/models/trip_for_vehicle_retrieve_params.rb
Overview
Instance Attribute Summary collapse
-
#include_schedule ⇒ Boolean?
Determines whether full <schedule/> element is included in the <tripDetails/> section.
-
#include_status ⇒ Boolean?
Determines whether the full <status/> element is included in the <tripDetails/> section.
-
#include_trip ⇒ Boolean?
Determines whether full <trip/> element is included in the <references/> section.
-
#time ⇒ Integer?
Time parameter to query the system at a specific time (optional).
- #vehicle_id ⇒ String
Attributes included from Internal::Type::RequestParameters
Instance Method Summary collapse
-
#initialize(vehicle_id:, include_schedule: nil, include_status: nil, include_trip: nil, time: nil, request_options: {}) ⇒ Object
constructor
Some parameter documentations has been truncated, see TripForVehicleRetrieveParams for more details.
Methods included from Internal::Type::RequestParameters::Converter
Methods included from Internal::Type::RequestParameters
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(vehicle_id:, include_schedule: nil, include_status: nil, include_trip: nil, time: nil, request_options: {}) ⇒ Object
Some parameter documentations has been truncated, see OnebusawaySDK::Models::TripForVehicleRetrieveParams for more details.
|
|
# File 'lib/onebusaway_sdk/models/trip_for_vehicle_retrieve_params.rb', line 42
|
Instance Attribute Details
#include_schedule ⇒ Boolean?
Determines whether full <schedule/> element is included in the <tripDetails/> section. Defaults to false.
20 |
# File 'lib/onebusaway_sdk/models/trip_for_vehicle_retrieve_params.rb', line 20 optional :include_schedule, OnebusawaySDK::Internal::Type::Boolean |
#include_status ⇒ Boolean?
Determines whether the full <status/> element is included in the <tripDetails/> section. Defaults to true.
27 |
# File 'lib/onebusaway_sdk/models/trip_for_vehicle_retrieve_params.rb', line 27 optional :include_status, OnebusawaySDK::Internal::Type::Boolean |
#include_trip ⇒ Boolean?
Determines whether full <trip/> element is included in the <references/> section. Defaults to false.
34 |
# File 'lib/onebusaway_sdk/models/trip_for_vehicle_retrieve_params.rb', line 34 optional :include_trip, OnebusawaySDK::Internal::Type::Boolean |
#time ⇒ Integer?
Time parameter to query the system at a specific time (optional).
40 |
# File 'lib/onebusaway_sdk/models/trip_for_vehicle_retrieve_params.rb', line 40 optional :time, Integer |
#vehicle_id ⇒ String
13 |
# File 'lib/onebusaway_sdk/models/trip_for_vehicle_retrieve_params.rb', line 13 required :vehicle_id, String |