Class: OnebusawaySDK::Models::TripForVehicleRetrieveResponse::Data::Entry::Status::LastKnownLocation
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- OnebusawaySDK::Models::TripForVehicleRetrieveResponse::Data::Entry::Status::LastKnownLocation
- Defined in:
- lib/onebusaway_sdk/models/trip_for_vehicle_retrieve_response.rb,
sig/onebusaway_sdk/models/trip_for_vehicle_retrieve_response.rbs
Overview
Instance Attribute Summary collapse
-
#lat ⇒ Float?
Latitude of the last known location of the transit vehicle.
-
#lon ⇒ Float?
Longitude of the last known location of the transit vehicle.
Instance Method Summary collapse
-
#initialize ⇒ LastKnownLocation
constructor
A new instance of LastKnownLocation.
- #to_hash ⇒ { lat: Float, lon: Float }
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize ⇒ LastKnownLocation
Returns a new instance of LastKnownLocation.
359 |
# File 'sig/onebusaway_sdk/models/trip_for_vehicle_retrieve_response.rbs', line 359
def initialize: (?lat: Float, ?lon: Float) -> void
|
Instance Attribute Details
#lat ⇒ Float?
Latitude of the last known location of the transit vehicle.
395 |
# File 'lib/onebusaway_sdk/models/trip_for_vehicle_retrieve_response.rb', line 395 optional :lat, Float |
#lon ⇒ Float?
Longitude of the last known location of the transit vehicle.
401 |
# File 'lib/onebusaway_sdk/models/trip_for_vehicle_retrieve_response.rb', line 401 optional :lon, Float |
Instance Method Details
#to_hash ⇒ { lat: Float, lon: Float }
361 |
# File 'sig/onebusaway_sdk/models/trip_for_vehicle_retrieve_response.rbs', line 361
def to_hash: -> { lat: Float, lon: Float }
|