Class: OnebusawaySDK::Models::TripsForLocationListResponse::Data::List::Status

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/onebusaway_sdk/models/trips_for_location_list_response.rb

Overview

See Also:

Defined Under Namespace

Classes: LastKnownLocation, Position

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(lat: nil, lon: nil) ⇒ Object

Last known location of the transit vehicle (optional).

Parameters:

  • lat (Float) (defaults to: nil)

    Latitude of the last known location of the transit vehicle.

  • lon (Float) (defaults to: nil)

    Longitude of the last known location of the transit vehicle.



# File 'lib/onebusaway_sdk/models/trips_for_location_list_response.rb', line 343

Instance Attribute Details

#active_trip_idString

Trip ID of the trip the vehicle is actively serving.

Returns:

  • (String)


176
# File 'lib/onebusaway_sdk/models/trips_for_location_list_response.rb', line 176

required :active_trip_id, String, api_name: :activeTripId

#block_trip_sequenceInteger

Index of the active trip into the sequence of trips for the active block.

Returns:

  • (Integer)


182
# File 'lib/onebusaway_sdk/models/trips_for_location_list_response.rb', line 182

required :block_trip_sequence, Integer, api_name: :blockTripSequence

#closest_stopString

ID of the closest stop to the current location of the transit vehicle.

Returns:

  • (String)


188
# File 'lib/onebusaway_sdk/models/trips_for_location_list_response.rb', line 188

required :closest_stop, String, api_name: :closestStop

#closest_stop_time_offsetInteger?

Time offset from the closest stop to the current position of the transit vehicle (in seconds).

Returns:

  • (Integer, nil)


275
# File 'lib/onebusaway_sdk/models/trips_for_location_list_response.rb', line 275

optional :closest_stop_time_offset, Integer, api_name: :closestStopTimeOffset

#distance_along_tripFloat

Distance, in meters, the transit vehicle has progressed along the active trip.

Returns:

  • (Float)


194
# File 'lib/onebusaway_sdk/models/trips_for_location_list_response.rb', line 194

required :distance_along_trip, Float, api_name: :distanceAlongTrip

#frequencyString?

Information about frequency-based scheduling, if applicable to the trip.

Returns:

  • (String, nil)


281
# File 'lib/onebusaway_sdk/models/trips_for_location_list_response.rb', line 281

optional :frequency, String

#last_known_distance_along_tripFloat

Last known distance along the trip received in real-time from the transit vehicle.

Returns:

  • (Float)


201
# File 'lib/onebusaway_sdk/models/trips_for_location_list_response.rb', line 201

required :last_known_distance_along_trip, Float, api_name: :lastKnownDistanceAlongTrip

#last_known_locationOnebusawaySDK::Models::TripsForLocationListResponse::Data::List::Status::LastKnownLocation?

Last known location of the transit vehicle (optional).



287
288
289
290
# File 'lib/onebusaway_sdk/models/trips_for_location_list_response.rb', line 287

optional :last_known_location,
-> { OnebusawaySDK::Models::TripsForLocationListResponse::Data::List::Status::LastKnownLocation },
api_name: :lastKnownLocation,
nil?: true

#last_known_orientationFloat?

Last known orientation value received in real-time from the transit vehicle.

Returns:

  • (Float, nil)


296
# File 'lib/onebusaway_sdk/models/trips_for_location_list_response.rb', line 296

optional :last_known_orientation, Float, api_name: :lastKnownOrientation

#last_location_update_timeInteger

Timestamp of the last known real-time location update from the transit vehicle.

Returns:

  • (Integer)


207
# File 'lib/onebusaway_sdk/models/trips_for_location_list_response.rb', line 207

required :last_location_update_time, Integer, api_name: :lastLocationUpdateTime

#last_update_timeInteger

Timestamp of the last known real-time update from the transit vehicle.

Returns:

  • (Integer)


213
# File 'lib/onebusaway_sdk/models/trips_for_location_list_response.rb', line 213

required :last_update_time, Integer, api_name: :lastUpdateTime

#next_stopString?

ID of the next stop the transit vehicle is scheduled to arrive at.

Returns:

  • (String, nil)


302
# File 'lib/onebusaway_sdk/models/trips_for_location_list_response.rb', line 302

optional :next_stop, String, api_name: :nextStop

#next_stop_time_offsetInteger?

Time offset from the next stop to the current position of the transit vehicle (in seconds).

Returns:

  • (Integer, nil)


309
# File 'lib/onebusaway_sdk/models/trips_for_location_list_response.rb', line 309

optional :next_stop_time_offset, Integer, api_name: :nextStopTimeOffset

#occupancy_capacityInteger

Capacity of the transit vehicle in terms of occupancy.

Returns:

  • (Integer)


219
# File 'lib/onebusaway_sdk/models/trips_for_location_list_response.rb', line 219

required :occupancy_capacity, Integer, api_name: :occupancyCapacity

#occupancy_countInteger

Current count of occupants in the transit vehicle.

Returns:

  • (Integer)


225
# File 'lib/onebusaway_sdk/models/trips_for_location_list_response.rb', line 225

required :occupancy_count, Integer, api_name: :occupancyCount

#occupancy_statusString

Current occupancy status of the transit vehicle.

Returns:

  • (String)


231
# File 'lib/onebusaway_sdk/models/trips_for_location_list_response.rb', line 231

required :occupancy_status, String, api_name: :occupancyStatus

#orientationFloat?

Orientation of the transit vehicle, represented as an angle in degrees.

Returns:

  • (Float, nil)


315
# File 'lib/onebusaway_sdk/models/trips_for_location_list_response.rb', line 315

optional :orientation, Float

#phaseString

Current journey phase of the trip.

Returns:

  • (String)


237
# File 'lib/onebusaway_sdk/models/trips_for_location_list_response.rb', line 237

required :phase, String

#positionOnebusawaySDK::Models::TripsForLocationListResponse::Data::List::Status::Position?

Current position of the transit vehicle.



321
322
# File 'lib/onebusaway_sdk/models/trips_for_location_list_response.rb', line 321

optional :position,
-> { OnebusawaySDK::Models::TripsForLocationListResponse::Data::List::Status::Position }

#predictedBoolean

Indicates if real-time arrival info is available for this trip.

Returns:

  • (Boolean)


243
# File 'lib/onebusaway_sdk/models/trips_for_location_list_response.rb', line 243

required :predicted, OnebusawaySDK::Internal::Type::Boolean

#schedule_deviationInteger

Deviation from the schedule in seconds (positive for late, negative for early).

Returns:

  • (Integer)


249
# File 'lib/onebusaway_sdk/models/trips_for_location_list_response.rb', line 249

required :schedule_deviation, Integer, api_name: :scheduleDeviation

#scheduled_distance_along_tripFloat?

Distance, in meters, the transit vehicle is scheduled to have progressed along the active trip.

Returns:

  • (Float, nil)


329
# File 'lib/onebusaway_sdk/models/trips_for_location_list_response.rb', line 329

optional :scheduled_distance_along_trip, Float, api_name: :scheduledDistanceAlongTrip

#service_dateInteger

Time, in milliseconds since the Unix epoch, of midnight for the start of the service date for the trip.

Returns:

  • (Integer)


256
# File 'lib/onebusaway_sdk/models/trips_for_location_list_response.rb', line 256

required :service_date, Integer, api_name: :serviceDate

#situation_idsArray<String>?

References to situation elements (if any) applicable to this trip.

Returns:

  • (Array<String>, nil)


335
# File 'lib/onebusaway_sdk/models/trips_for_location_list_response.rb', line 335

optional :situation_ids, OnebusawaySDK::Internal::Type::ArrayOf[String], api_name: :situationIds

#statusString

Current status modifiers for the trip.

Returns:

  • (String)


262
# File 'lib/onebusaway_sdk/models/trips_for_location_list_response.rb', line 262

required :status, String

#total_distance_along_tripFloat

Total length of the trip, in meters.

Returns:

  • (Float)


268
# File 'lib/onebusaway_sdk/models/trips_for_location_list_response.rb', line 268

required :total_distance_along_trip, Float, api_name: :totalDistanceAlongTrip

#vehicle_idString?

ID of the transit vehicle currently serving the trip.

Returns:

  • (String, nil)


341
# File 'lib/onebusaway_sdk/models/trips_for_location_list_response.rb', line 341

optional :vehicle_id, String, api_name: :vehicleId