Class: OnebusawaySDK::Models::VehiclesForAgencyListResponse::Data::List::TripStatus::LastKnownLocation

Inherits:
Internal::Type::BaseModel
  • Object
show all
Defined in:
lib/onebusaway_sdk/models/vehicles_for_agency_list_response.rb,
sig/onebusaway_sdk/models/vehicles_for_agency_list_response.rbs

Overview

See Also:

  • OnebusawaySDK::Models::VehiclesForAgencyListResponse::Data::List::TripStatus#last_known_location

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initializeLastKnownLocation

Returns a new instance of LastKnownLocation.

Parameters:

  • lat: (Float)
  • lon: (Float)


328
# File 'sig/onebusaway_sdk/models/vehicles_for_agency_list_response.rbs', line 328

def initialize: (?lat: Float, ?lon: Float) -> void

Instance Attribute Details

#latFloat?

Latitude of the last known location of the transit vehicle.

Parameters:

  • (Float)

Returns:

  • (Float, nil)


376
# File 'lib/onebusaway_sdk/models/vehicles_for_agency_list_response.rb', line 376

optional :lat, Float

#lonFloat?

Longitude of the last known location of the transit vehicle.

Parameters:

  • (Float)

Returns:

  • (Float, nil)


382
# File 'lib/onebusaway_sdk/models/vehicles_for_agency_list_response.rb', line 382

optional :lon, Float

Instance Method Details

#to_hash{ lat: Float, lon: Float }

Returns:

  • ({ lat: Float, lon: Float })


330
# File 'sig/onebusaway_sdk/models/vehicles_for_agency_list_response.rbs', line 330

def to_hash: -> { lat: Float, lon: Float }