Class: OnebusawaySDK::Models::ArrivalsAndDeparturesForLocationListParams
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- OnebusawaySDK::Models::ArrivalsAndDeparturesForLocationListParams
- Extended by:
- Internal::Type::RequestParameters::Converter
- Includes:
- Internal::Type::RequestParameters
- Defined in:
- lib/onebusaway_sdk/models/arrivals_and_departures_for_location_list_params.rb
Overview
Instance Attribute Summary collapse
-
#empty_returns_not_found ⇒ Boolean?
If true, returns a 404 Not Found error instead of an empty result.
-
#lat ⇒ Float
The latitude coordinate of the search center.
-
#lat_span ⇒ Float?
Sets the latitude limits of the search bounding box.
-
#lon ⇒ Float
The longitude coordinate of the search center.
-
#lon_span ⇒ Float?
Sets the longitude limits of the search bounding box.
-
#max_count ⇒ Integer?
The max size of the list of nearby stops and arrivals to return.
-
#minutes_after ⇒ Integer?
Include arrivals and departures this many minutes after the query time.
-
#minutes_before ⇒ Integer?
Include arrivals and departures this many minutes before the query time.
-
#radius ⇒ Float?
The search radius in meters.
-
#route_type ⇒ String?
Optional list of GTFS routeTypes to filter by (comma delimited) e.g.
-
#time ⇒ Integer?
By default, returns the status right now.
Attributes included from Internal::Type::RequestParameters
Instance Method Summary collapse
-
#initialize(lat:, lon:, empty_returns_not_found: nil, lat_span: nil, lon_span: nil, max_count: nil, minutes_after: nil, minutes_before: nil, radius: nil, route_type: nil, time: nil, request_options: {}) ⇒ Object
constructor
Some parameter documentations has been truncated, see ArrivalsAndDeparturesForLocationListParams for more details.
Methods included from Internal::Type::RequestParameters::Converter
Methods included from Internal::Type::RequestParameters
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(lat:, lon:, empty_returns_not_found: nil, lat_span: nil, lon_span: nil, max_count: nil, minutes_after: nil, minutes_before: nil, radius: nil, route_type: nil, time: nil, request_options: {}) ⇒ Object
Some parameter documentations has been truncated, see OnebusawaySDK::Models::ArrivalsAndDeparturesForLocationListParams for more details.
|
|
# File 'lib/onebusaway_sdk/models/arrivals_and_departures_for_location_list_params.rb', line 78
|
Instance Attribute Details
#empty_returns_not_found ⇒ Boolean?
If true, returns a 404 Not Found error instead of an empty result.
26 |
# File 'lib/onebusaway_sdk/models/arrivals_and_departures_for_location_list_params.rb', line 26 optional :empty_returns_not_found, OnebusawaySDK::Internal::Type::Boolean |
#lat ⇒ Float
The latitude coordinate of the search center.
14 |
# File 'lib/onebusaway_sdk/models/arrivals_and_departures_for_location_list_params.rb', line 14 required :lat, Float |
#lat_span ⇒ Float?
Sets the latitude limits of the search bounding box.
32 |
# File 'lib/onebusaway_sdk/models/arrivals_and_departures_for_location_list_params.rb', line 32 optional :lat_span, Float |
#lon ⇒ Float
The longitude coordinate of the search center.
20 |
# File 'lib/onebusaway_sdk/models/arrivals_and_departures_for_location_list_params.rb', line 20 required :lon, Float |
#lon_span ⇒ Float?
Sets the longitude limits of the search bounding box.
38 |
# File 'lib/onebusaway_sdk/models/arrivals_and_departures_for_location_list_params.rb', line 38 optional :lon_span, Float |
#max_count ⇒ Integer?
The max size of the list of nearby stops and arrivals to return. Defaults to 250, max 1000.
45 |
# File 'lib/onebusaway_sdk/models/arrivals_and_departures_for_location_list_params.rb', line 45 optional :max_count, Integer |
#minutes_after ⇒ Integer?
Include arrivals and departures this many minutes after the query time.
51 |
# File 'lib/onebusaway_sdk/models/arrivals_and_departures_for_location_list_params.rb', line 51 optional :minutes_after, Integer |
#minutes_before ⇒ Integer?
Include arrivals and departures this many minutes before the query time.
57 |
# File 'lib/onebusaway_sdk/models/arrivals_and_departures_for_location_list_params.rb', line 57 optional :minutes_before, Integer |
#radius ⇒ Float?
The search radius in meters.
63 |
# File 'lib/onebusaway_sdk/models/arrivals_and_departures_for_location_list_params.rb', line 63 optional :radius, Float |
#route_type ⇒ String?
Optional list of GTFS routeTypes to filter by (comma delimited) e.g. “1,2,3”.
69 |
# File 'lib/onebusaway_sdk/models/arrivals_and_departures_for_location_list_params.rb', line 69 optional :route_type, String |
#time ⇒ Integer?
By default, returns the status right now. Can be queried at a specific time (milliseconds since epoch) for testing.
76 |
# File 'lib/onebusaway_sdk/models/arrivals_and_departures_for_location_list_params.rb', line 76 optional :time, Integer |