Class: OnebusawaySDK::Models::TripDetailRetrieveParams
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- OnebusawaySDK::Models::TripDetailRetrieveParams
- Extended by:
- Internal::Type::RequestParameters::Converter
- Includes:
- Internal::Type::RequestParameters
- Defined in:
- lib/onebusaway_sdk/models/trip_detail_retrieve_params.rb
Overview
Instance Attribute Summary collapse
-
#include_schedule ⇒ Boolean?
Whether to include the full schedule element in the tripDetails section (defaults to true).
-
#include_status ⇒ Boolean?
Whether to include the full status element in the tripDetails section (defaults to true).
-
#include_trip ⇒ Boolean?
Whether to include the full trip element in the references section (defaults to true).
-
#service_date ⇒ Integer?
Service date for the trip as Unix time in milliseconds (optional).
-
#time ⇒ Integer?
Time parameter to query the system at a specific time (optional).
- #trip_id ⇒ String
Attributes included from Internal::Type::RequestParameters
Instance Method Summary collapse
-
#initialize(trip_id:, include_schedule: nil, include_status: nil, include_trip: nil, service_date: nil, time: nil, request_options: {}) ⇒ Object
constructor
Some parameter documentations has been truncated, see TripDetailRetrieveParams for more details.
Methods included from Internal::Type::RequestParameters::Converter
Methods included from Internal::Type::RequestParameters
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(trip_id:, include_schedule: nil, include_status: nil, include_trip: nil, service_date: nil, time: nil, request_options: {}) ⇒ Object
Some parameter documentations has been truncated, see OnebusawaySDK::Models::TripDetailRetrieveParams for more details.
|
|
# File 'lib/onebusaway_sdk/models/trip_detail_retrieve_params.rb', line 48
|
Instance Attribute Details
#include_schedule ⇒ Boolean?
Whether to include the full schedule element in the tripDetails section (defaults to true).
20 |
# File 'lib/onebusaway_sdk/models/trip_detail_retrieve_params.rb', line 20 optional :include_schedule, OnebusawaySDK::Internal::Type::Boolean |
#include_status ⇒ Boolean?
Whether to include the full status element in the tripDetails section (defaults to true).
27 |
# File 'lib/onebusaway_sdk/models/trip_detail_retrieve_params.rb', line 27 optional :include_status, OnebusawaySDK::Internal::Type::Boolean |
#include_trip ⇒ Boolean?
Whether to include the full trip element in the references section (defaults to true).
34 |
# File 'lib/onebusaway_sdk/models/trip_detail_retrieve_params.rb', line 34 optional :include_trip, OnebusawaySDK::Internal::Type::Boolean |
#service_date ⇒ Integer?
Service date for the trip as Unix time in milliseconds (optional).
40 |
# File 'lib/onebusaway_sdk/models/trip_detail_retrieve_params.rb', line 40 optional :service_date, Integer |
#time ⇒ Integer?
Time parameter to query the system at a specific time (optional).
46 |
# File 'lib/onebusaway_sdk/models/trip_detail_retrieve_params.rb', line 46 optional :time, Integer |
#trip_id ⇒ String
13 |
# File 'lib/onebusaway_sdk/models/trip_detail_retrieve_params.rb', line 13 required :trip_id, String |