Class: OnebusawaySDK::Models::TripDetailRetrieveResponse::Data::Entry::Status
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- OnebusawaySDK::Models::TripDetailRetrieveResponse::Data::Entry::Status
- Defined in:
- lib/onebusaway_sdk/models/trip_detail_retrieve_response.rb
Overview
Defined Under Namespace
Classes: LastKnownLocation, Position
Instance Attribute Summary collapse
-
#active_trip_id ⇒ String
Trip ID of the trip the vehicle is actively serving.
-
#block_trip_sequence ⇒ Integer
Index of the active trip into the sequence of trips for the active block.
-
#closest_stop ⇒ String
ID of the closest stop to the current location of the transit vehicle.
-
#closest_stop_time_offset ⇒ Integer?
Time offset from the closest stop to the current position of the transit vehicle (in seconds).
-
#distance_along_trip ⇒ Float
Distance, in meters, the transit vehicle has progressed along the active trip.
-
#frequency ⇒ String?
Information about frequency-based scheduling, if applicable to the trip.
-
#last_known_distance_along_trip ⇒ Float
Last known distance along the trip received in real-time from the transit vehicle.
-
#last_known_location ⇒ OnebusawaySDK::Models::TripDetailRetrieveResponse::Data::Entry::Status::LastKnownLocation?
Last known location of the transit vehicle (optional).
-
#last_known_orientation ⇒ Float?
Last known orientation value received in real-time from the transit vehicle.
-
#last_location_update_time ⇒ Integer
Timestamp of the last known real-time location update from the transit vehicle.
-
#last_update_time ⇒ Integer
Timestamp of the last known real-time update from the transit vehicle.
-
#next_stop ⇒ String?
ID of the next stop the transit vehicle is scheduled to arrive at.
-
#next_stop_time_offset ⇒ Integer?
Time offset from the next stop to the current position of the transit vehicle (in seconds).
-
#occupancy_capacity ⇒ Integer
Capacity of the transit vehicle in terms of occupancy.
-
#occupancy_count ⇒ Integer
Current count of occupants in the transit vehicle.
-
#occupancy_status ⇒ String
Current occupancy status of the transit vehicle.
-
#orientation ⇒ Float?
Orientation of the transit vehicle, represented as an angle in degrees.
-
#phase ⇒ String
Current journey phase of the trip.
-
#position ⇒ OnebusawaySDK::Models::TripDetailRetrieveResponse::Data::Entry::Status::Position?
Current position of the transit vehicle.
-
#predicted ⇒ Boolean
Indicates if real-time arrival info is available for this trip.
-
#schedule_deviation ⇒ Integer
Deviation from the schedule in seconds (positive for late, negative for early).
-
#scheduled_distance_along_trip ⇒ Float?
Distance, in meters, the transit vehicle is scheduled to have progressed along the active trip.
-
#service_date ⇒ Integer
Time, in milliseconds since the Unix epoch, of midnight for the start of the service date for the trip.
-
#situation_ids ⇒ Array<String>?
References to situation elements (if any) applicable to this trip.
-
#status ⇒ String
Current status modifiers for the trip.
-
#total_distance_along_trip ⇒ Float
Total length of the trip, in meters.
-
#vehicle_id ⇒ String?
ID of the transit vehicle currently serving the trip.
Instance Method Summary collapse
-
#initialize(lat: nil, lon: nil) ⇒ Object
constructor
Last known location of the transit vehicle (optional).
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(lat: nil, lon: nil) ⇒ Object
Last known location of the transit vehicle (optional).
|
|
# File 'lib/onebusaway_sdk/models/trip_detail_retrieve_response.rb', line 328
|
Instance Attribute Details
#active_trip_id ⇒ String
Trip ID of the trip the vehicle is actively serving.
161 |
# File 'lib/onebusaway_sdk/models/trip_detail_retrieve_response.rb', line 161 required :active_trip_id, String, api_name: :activeTripId |
#block_trip_sequence ⇒ Integer
Index of the active trip into the sequence of trips for the active block.
167 |
# File 'lib/onebusaway_sdk/models/trip_detail_retrieve_response.rb', line 167 required :block_trip_sequence, Integer, api_name: :blockTripSequence |
#closest_stop ⇒ String
ID of the closest stop to the current location of the transit vehicle.
173 |
# File 'lib/onebusaway_sdk/models/trip_detail_retrieve_response.rb', line 173 required :closest_stop, String, api_name: :closestStop |
#closest_stop_time_offset ⇒ Integer?
Time offset from the closest stop to the current position of the transit vehicle (in seconds).
260 |
# File 'lib/onebusaway_sdk/models/trip_detail_retrieve_response.rb', line 260 optional :closest_stop_time_offset, Integer, api_name: :closestStopTimeOffset |
#distance_along_trip ⇒ Float
Distance, in meters, the transit vehicle has progressed along the active trip.
179 |
# File 'lib/onebusaway_sdk/models/trip_detail_retrieve_response.rb', line 179 required :distance_along_trip, Float, api_name: :distanceAlongTrip |
#frequency ⇒ String?
Information about frequency-based scheduling, if applicable to the trip.
266 |
# File 'lib/onebusaway_sdk/models/trip_detail_retrieve_response.rb', line 266 optional :frequency, String, nil?: true |
#last_known_distance_along_trip ⇒ Float
Last known distance along the trip received in real-time from the transit vehicle.
186 |
# File 'lib/onebusaway_sdk/models/trip_detail_retrieve_response.rb', line 186 required :last_known_distance_along_trip, Float, api_name: :lastKnownDistanceAlongTrip |
#last_known_location ⇒ OnebusawaySDK::Models::TripDetailRetrieveResponse::Data::Entry::Status::LastKnownLocation?
Last known location of the transit vehicle (optional).
272 273 274 275 |
# File 'lib/onebusaway_sdk/models/trip_detail_retrieve_response.rb', line 272 optional :last_known_location, -> { OnebusawaySDK::Models::TripDetailRetrieveResponse::Data::Entry::Status::LastKnownLocation }, api_name: :lastKnownLocation, nil?: true |
#last_known_orientation ⇒ Float?
Last known orientation value received in real-time from the transit vehicle.
281 |
# File 'lib/onebusaway_sdk/models/trip_detail_retrieve_response.rb', line 281 optional :last_known_orientation, Float, api_name: :lastKnownOrientation |
#last_location_update_time ⇒ Integer
Timestamp of the last known real-time location update from the transit vehicle.
192 |
# File 'lib/onebusaway_sdk/models/trip_detail_retrieve_response.rb', line 192 required :last_location_update_time, Integer, api_name: :lastLocationUpdateTime |
#last_update_time ⇒ Integer
Timestamp of the last known real-time update from the transit vehicle.
198 |
# File 'lib/onebusaway_sdk/models/trip_detail_retrieve_response.rb', line 198 required :last_update_time, Integer, api_name: :lastUpdateTime |
#next_stop ⇒ String?
ID of the next stop the transit vehicle is scheduled to arrive at.
287 |
# File 'lib/onebusaway_sdk/models/trip_detail_retrieve_response.rb', line 287 optional :next_stop, String, api_name: :nextStop |
#next_stop_time_offset ⇒ Integer?
Time offset from the next stop to the current position of the transit vehicle (in seconds).
294 |
# File 'lib/onebusaway_sdk/models/trip_detail_retrieve_response.rb', line 294 optional :next_stop_time_offset, Integer, api_name: :nextStopTimeOffset |
#occupancy_capacity ⇒ Integer
Capacity of the transit vehicle in terms of occupancy.
204 |
# File 'lib/onebusaway_sdk/models/trip_detail_retrieve_response.rb', line 204 required :occupancy_capacity, Integer, api_name: :occupancyCapacity |
#occupancy_count ⇒ Integer
Current count of occupants in the transit vehicle.
210 |
# File 'lib/onebusaway_sdk/models/trip_detail_retrieve_response.rb', line 210 required :occupancy_count, Integer, api_name: :occupancyCount |
#occupancy_status ⇒ String
Current occupancy status of the transit vehicle.
216 |
# File 'lib/onebusaway_sdk/models/trip_detail_retrieve_response.rb', line 216 required :occupancy_status, String, api_name: :occupancyStatus |
#orientation ⇒ Float?
Orientation of the transit vehicle, represented as an angle in degrees.
300 |
# File 'lib/onebusaway_sdk/models/trip_detail_retrieve_response.rb', line 300 optional :orientation, Float |
#phase ⇒ String
Current journey phase of the trip.
222 |
# File 'lib/onebusaway_sdk/models/trip_detail_retrieve_response.rb', line 222 required :phase, String |
#position ⇒ OnebusawaySDK::Models::TripDetailRetrieveResponse::Data::Entry::Status::Position?
Current position of the transit vehicle.
306 307 |
# File 'lib/onebusaway_sdk/models/trip_detail_retrieve_response.rb', line 306 optional :position, -> { OnebusawaySDK::Models::TripDetailRetrieveResponse::Data::Entry::Status::Position } |
#predicted ⇒ Boolean
Indicates if real-time arrival info is available for this trip.
228 |
# File 'lib/onebusaway_sdk/models/trip_detail_retrieve_response.rb', line 228 required :predicted, OnebusawaySDK::Internal::Type::Boolean |
#schedule_deviation ⇒ Integer
Deviation from the schedule in seconds (positive for late, negative for early).
234 |
# File 'lib/onebusaway_sdk/models/trip_detail_retrieve_response.rb', line 234 required :schedule_deviation, Integer, api_name: :scheduleDeviation |
#scheduled_distance_along_trip ⇒ Float?
Distance, in meters, the transit vehicle is scheduled to have progressed along the active trip.
314 |
# File 'lib/onebusaway_sdk/models/trip_detail_retrieve_response.rb', line 314 optional :scheduled_distance_along_trip, Float, api_name: :scheduledDistanceAlongTrip |
#service_date ⇒ Integer
Time, in milliseconds since the Unix epoch, of midnight for the start of the service date for the trip.
241 |
# File 'lib/onebusaway_sdk/models/trip_detail_retrieve_response.rb', line 241 required :service_date, Integer, api_name: :serviceDate |
#situation_ids ⇒ Array<String>?
References to situation elements (if any) applicable to this trip.
320 |
# File 'lib/onebusaway_sdk/models/trip_detail_retrieve_response.rb', line 320 optional :situation_ids, OnebusawaySDK::Internal::Type::ArrayOf[String], api_name: :situationIds |
#status ⇒ String
Current status modifiers for the trip.
247 |
# File 'lib/onebusaway_sdk/models/trip_detail_retrieve_response.rb', line 247 required :status, String |
#total_distance_along_trip ⇒ Float
Total length of the trip, in meters.
253 |
# File 'lib/onebusaway_sdk/models/trip_detail_retrieve_response.rb', line 253 required :total_distance_along_trip, Float, api_name: :totalDistanceAlongTrip |
#vehicle_id ⇒ String?
ID of the transit vehicle currently serving the trip.
326 |
# File 'lib/onebusaway_sdk/models/trip_detail_retrieve_response.rb', line 326 optional :vehicle_id, String, api_name: :vehicleId |